@@ -1,7 +1,7 @@
 package Sidef::Math::Math {
 
     use utf8;
-    use 5.016;
+    use 5.014;
 
     use parent qw(
       Sidef::Object::Object
@@ -13,97 +13,87 @@ package Sidef::Math::Math {
         bless {}, __PACKAGE__;
     }
 
-    sub binsplit {
-        my ($self, $block, @list) = @_;
-        Sidef::Types::Number::Number::_binsplit(\@list, $block);
-    }
-
     sub gcd {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::gcd(@list);
+
+        my $gcd = $list[0];
+        foreach my $i (1 .. $#list) {
+            last if ($gcd->is_one);
+            $gcd = $gcd->gcd($list[$i]);
+        }
+
+        $gcd;
     }
 
     sub lcm {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::lcm(@list);
+
+        my $lcm = $list[0];
+        foreach my $i (1 .. $#list) {
+            $lcm = $lcm->lcm($list[$i]);
+        }
+
+        $lcm;
     }
 
     sub sum {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::sum(@list);
+
+        my $sum = Sidef::Types::Number::Number::ZERO;
+        foreach my $n (@list) {
+            $sum = $sum->add($n);
+        }
+
+        $sum;
     }
 
     sub prod {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::prod(@list);
+
+        my $prod = Sidef::Types::Number::Number::ONE;
+        foreach my $n (@list) {
+            $prod = $prod->mul($n);
+        }
+
+        $prod;
     }
 
     *product = \&prod;
 
     sub max {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::max(@list);
+
+        my $max = $list[0];
+        foreach my $i (1 .. $#list) {
+            $max = $max->max($list[$i]);
+        }
+
+        $max;
     }
 
     sub min {
         my ($self, @list) = @_;
-        Sidef::Types::Number::Number::min(@list);
+
+        my $min = $list[0];
+        foreach my $i (1 .. $#list) {
+            $min = $min->min($list[$i]);
+        }
+
+        $min;
     }
 
-    sub arithmetic_mean {
+    sub avg {
         my ($self, @list) = @_;
 
-        my $sum = Sidef::Types::Number::Number::sum(@list);
-        my $n   = Sidef::Types::Number::Number->_set_uint(scalar(@list));
+        my $sum = Sidef::Types::Number::Number::ZERO;
+        foreach my $n (@list) {
+            $sum = $sum->add($n);
+        }
 
+        my $n = Sidef::Types::Number::Number->new(scalar(@list));
         $sum->div($n);
     }
 
-    *avg = \&arithmetic_mean;
-
-    sub geometric_mean {
-        my ($self, @list) = @_;
-
-        my $prod = Sidef::Types::Number::Number::prod(@list);
-        my $n    = Sidef::Types::Number::Number->_set_uint(scalar(@list));
-
-        $prod->root($n);
-    }
-
-    sub harmonic_mean {
-        my ($self, @list) = @_;
-
-        my $sum = Sidef::Types::Number::Number::sum(map { $_->inv } @list);
-        my $n   = Sidef::Types::Number::Number->_set_uint(scalar(@list));
-
-        $n->div($sum);
-    }
-
-    sub smooth_numbers {
-        my ($self, @primes) = @_;
-
-        my @s = map { [Sidef::Types::Number::Number::ONE] } @primes;
-
-        Sidef::Object::Enumerator->new(
-            Sidef::Types::Block::Block->new(
-                code => sub {
-                    my ($callback) = @_;
-
-                    while (1) {
-                        my $n = Sidef::Types::Number::Number::min(map { $_->[0] } @s);
-
-                        for my $i (0 .. $#primes) {
-                            shift(@{$s[$i]}) if $s[$i][0]->eq($n);
-                            push(@{$s[$i]}, $n->mul($primes[$i]));
-                        }
-
-                        $callback->run($n);
-                    }
-                }
-            )
-        );
-    }
-
     sub chinese {
         my ($self, @arrs) = @_;
 
@@ -122,11 +112,11 @@ package Sidef::Math::Math {
 
         my $res = eval { Math::Prime::Util::GMP::chinese(@pairs) } // return Sidef::Types::Number::Number->nan;
 
-        if ($res < Sidef::Types::Number::Number::ULONG_MAX and $res >= 0) {
+        if ($res <= Sidef::Types::Number::Number::ULONG_MAX and $res >= 0) {
             return Sidef::Types::Number::Number->_set_uint($res);
         }
 
-        Sidef::Types::Number::Number->_set_str('int', $res);
+        Sidef::Types::Number::Number->_set_str($res);
     }
 
     sub range_sum {
